@@ -28,6 +28,10 @@ DialogThemes = {
             Style('selectitem', 'Cyan', 'Base02', nowrap=True),
             Style('selectitem2', 'Yellow', 'Base02', nowrap=True),
             Style('selectitem-active', 'Base02', 'Yellow', nowrap=True),
+
+            Style('selectphrase', 'Black', 'Cyan', nowrap=True),
+            Style('selectphrase2', 'Yellow', 'Base02', nowrap=True),
+            Style('selectphrase-active', 'Base02', 'Yellow', nowrap=True),
     ])
 }
 
