@@ -12,7 +12,7 @@ MsgBoxThemes = {
             Style('separator', 'Menu1', 'Base02', nowrap=False),
             Style('button', 'Menu1', 'Base02', nowrap=True),
             Style('button.shortcut', 'Menu1', 'Base02', underline=True,
-                   bold=True, nowrap=True),
+                   nowrap=True),
         ])
 }
 
@@ -53,13 +53,14 @@ class MsgBoxMode(dialogmode.DialogMode):
         # return value
         if c:
             c = c.lower()
-        self._runcallback(c)
-
-        # Destroy popup window
-        if wnd:
-            popup = wnd.get_label('popup')
-            if popup:
-                popup.destroy()
+        try:
+            self._runcallback(c)
+        finally:
+            # Destroy popup window
+            if wnd:
+                popup = wnd.get_label('popup')
+                if popup:
+                    popup.destroy()
 
     def _runcallback(self, c):
         if self.callback:
